SystemOrganization addCategory: #GODFilter!

Object subclass: #FILTMainFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODFilter'!

!FILTMainFilter commentStamp: 'lcm 10/30/2014 16:41' prior: 0!
A FILTMainFilter is a class with filters for all applications, having some methods like filter:byContent and filter:byTitle.

Instance Variables
!

FILTMainFilter subclass: #FILTConferenceFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODFilter'!

!FILTConferenceFilter commentStamp: 'lcm 10/30/2014 16:41' prior: 0!
A FILTConferenceFilter is a class that filter conferences using GCSearchFilter.

Instance Variables
!

!FILTConferenceFilter methodsFor: 'accessing' stamp: 'ym 11/6/2014 19:54'!
filter: collectionOfGodConference byGCSearchFilter: searchFilter
	"Filter a collection of GODConference by GCSearchFilter.
	The output of this function is all g in collectionOfGodConference such that
		g keywords CONTAINS searchFilter keywords;
		g category CONTAINS searchFilter category;
		g importantDates deadlineDate <= searchFilter deadlineDate;
		g importantDates startDate => searchFilter startDate;
		g importantDates endDate <= searchFilter endDate;
	Empty searchFilter and collectionOfGodConference elements attributes are not checked"

	| result |
	result := OrderedCollection new.
	
	collectionOfGodConference do: [: each |
		(([each keywords includesAllOf: searchFilter keywords] on: MessageNotUnderstood do: [true]) & 
		([each categories includesAnyOf: searchFilter categories] on: MessageNotUnderstood do: [true]) & 
		([(each importantDates) deadlineDate <= (each importantDates) startDate] on: MessageNotUnderstood do: [true]) & 
		([(each importantDates) startDate <= (each importantDates) endDate] on: MessageNotUnderstood do: [true]) &
		([(each importantDates) deadlineDate <= searchFilter deadlineDate] on: MessageNotUnderstood do: [true]) & 
		([(each importantDates) startDate >= searchFilter startDate] on: MessageNotUnderstood do: [true]) & 
		([(each importantDates) endDate <= searchFilter endDate] on: MessageNotUnderstood do: [true]))
		ifTrue: [result add: each]].
	^result.! !

!FILTMainFilter methodsFor: 'accessing' stamp: 'LM 10/9/2014 19:32'!
filter: collectionOfGodData byContent: aString
	"Filter a collection of GODData by content"

	| result |
	result := OrderedCollection new.
	
	collectionOfGodData do: [: each |
		(aString match: each content)
		ifTrue: [result add: each]].
	^result.! !

!FILTMainFilter methodsFor: 'accessing' stamp: 'LM 10/9/2014 19:31'!
filter: collectionOfGodData byOrigin: aString
	"Filter a collection of GODData by origin"

	| result |
	result := OrderedCollection new.
	
	collectionOfGodData do: [: each |
		(aString match: each origin)
		ifTrue: [result add: each]].
	^result.! !

!FILTMainFilter methodsFor: 'accessing' stamp: 'LM 10/9/2014 19:33'!
filter: collectionOfGodData byTags: aString
	"Filter a collection of GODData by tags"

	| result |
	result := OrderedCollection new.
	
	collectionOfGodData do: [: each |
		each tags do: [:tag |
			(aString match: tag)
			ifTrue: [result add: each].
		]].
	^result. ! !

!FILTMainFilter methodsFor: 'accessing' stamp: 'LM 10/9/2014 19:31'!
filter: collectionOfGodData byTitle: aString
	"Filter a collection of GODData by title"

	| result |
	result := OrderedCollection new.
	
	collectionOfGodData do: [: each |
		(aString match: each title)
		ifTrue: [result add: each]].
	^result.! !

FILTMainFilter subclass: #FILTTextFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODFilter'!

!FILTTextFilter commentStamp: 'lcm 10/31/2014 10:03' prior: 0!
A FILTTextFilter is a class that filter a text returning some part of it.

Instance Variables
!

!FILTTextFilter methodsFor: 'accessing' stamp: 'lcm 11/7/2014 14:03'!
filterText: text between: startMark and: endMark 
	"Filter a string returning all substrings between an initial tag and a final tag"
	
	| result textSize startMarkSize endMarkSize initialIndex finalIndex index resultString |
	
	result := OrderedCollection new.
	textSize := text size.	
	startMarkSize := startMark size.
	endMarkSize := endMark size.
	initialIndex := text findString: startMark.
	finalIndex := text findString: endMark startingAt: initialIndex + startMarkSize.
	
	"Go through text if find start mark (initialIndex) and end mark (finalIndex) and end mark position is after start mark position"
	
	((initialIndex ~= 0) & (finalIndex ~= 0) & (finalIndex > initialIndex)) ifTrue: [ 
		[(finalIndex ~= 0)] whileTrue: [
			" Variable index contains next start mark after initialIndex. If it doesn't find next start mark, 
			then we copy the string between initialIndex and finalIndex to result and try to find next marks.
			If index is greater than finalIndex, then we copy the string between initialIndex and finalIndex to result, 
			rename index to initialIndex and try to find next end mark after initialIndex.
			If index is between initialIndex and finalIndex, then we discard the initialIndex and rename index to initialIndex. "
			index := text findString: startMark startingAt: initialIndex + 1.
			(index = 0) ifTrue: [resultString := text copyFrom: (initialIndex + startMarkSize) to: (finalIndex - 1).
   						           result add: resultString.
							     finalIndex := 0.]
						ifFalse: [(index > finalIndex) ifTrue: [ resultString := text copyFrom: (initialIndex + startMarkSize) to: (finalIndex - 1).
												  			 result add: resultString.
															 initialIndex := index.
															 finalIndex := text findString: endMark startingAt: initialIndex + startMarkSize.
															]
													ifFalse: [ (index > initialIndex) ifTrue: [ initialIndex := index. ]]].
						].].
	
	^result.! !
